@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,13 +19,13 @@
 #ifndef SIEVEACTIONLIST_H
 #define SIEVEACTIONLIST_H
 
-#include <QList>
+#include <QVector>
 
 namespace KSieveUi {
 class SieveAction;
 class SieveEditorGraphicalModeWidget;
 namespace SieveActionList {
-Q_REQUIRED_RESULT QList<KSieveUi::SieveAction *> actionList(KSieveUi::SieveEditorGraphicalModeWidget *graphicalModeWidget);
+Q_REQUIRED_RESULT QVector<KSieveUi::SieveAction *> actionList(KSieveUi::SieveEditorGraphicalModeWidget *graphicalModeWidget);
 }
 }
 
