@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -57,7 +57,7 @@ SieveTextEditWidget::~SieveTextEditWidget()
 void SieveTextEditWidget::initialize(KSieveUi::SieveTextEdit *custom)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     if (custom) {
         d->mTextEdit = custom;
     } else {
